/******************************************************************************************
Description	: 	Stored Process to create a ddcf plan

Creation Date	: 	February 2011

History 	: April 2011 - Added macro call for Model table
			March 2013 - Added macro to resolve dual selector issue.
		
	

Input parameters : plan_id

******************************************************************************************/
/*options mprint mlogic symbolgen;*/

%macro ddcf_create_forecast_plan;

%if &GL_FRAMEWORK_DB_IND.=&GL_SHORT_NO. %then %do;
	libname uiart MYSQL  INSERTBUFF=&GL_MYSQL_INSERTBUFF. DBINDEX=YES bulkload = yes  ESCAPE_BACKSLASH=YES MYSQL_PORT=3306 DBCONINIT = &GL_MYSQL_DBCONINIT.
	DATABASE=&GL_TRANS_DATABASE_NM. SERVER="&GL_TRANS_DB_SERVER."  authdomain = &GL_MYSQL_AUTH_DOMAIN. ; 
%end;

%global job_rc  userName passwd GL_FS_PROJ_DESKTOP;

%let GL_FS_PROJ_DESKTOP=NO;

	%global plan_id edit_flag;
	%let plan_id= &planid;
	%local plan_status ;

    /*for testing*/
    %let ui_libref=uiart;

	/* Define connection string for transactional server*/
	%ddcf_connect_to_trans_db;

	%ddcf_declare_global_variables;

	/*for deleting the plan*/
	%if &edit_flag.=1 %then %do;
		%ddcf_delete_plan;
	 	proc sql noprint;
			select count(*) into: plan_error
			     from uiart.plan_details 
				where plan_id=&plan_id.
				and PLAN_STATUS_NO=6;
			quit;

			%let plan_error=&plan_error.;
	/* if any error has occured while deletion of fs proj then go to end and update the 
			plan_operation and plan_details table as 'error while deletion'*/
			%if &plan_error.>0 %then %do;	
			
				%goto end_plan;

			%end;
	%end;

	/* Start: To address dual selector issue. */

	/* Check whether Create and Refresh Scenario. If refresh then do not derive leaf members.  */

	%let table_exist = %sysfunc(exist(abt.Plan_hier_filtered_leaf_val%sysfunc(ktrim(%sysfunc(kleft(&plan_id.))))));

	%if &table_exist. eq 0 %then %do;
		%ddcf_derive_plan_leaf_members(plan_id=&plan_id.,uiart=uiart);
	%end;

	/* End: To address dual selector issue. */

	/* For Creating the table with the total thread number for each plan */
	%let table_exist = %sysfunc(exist(config.plan_thread));
    %if &table_exist. eq 0 %then %do;
        proc sql noprint;
                 create table config.plan_thread 
                 (
                   plan_id num format = best12. informat = best12.,
                   thread_num num format = best12. informat = best12.
                  );
                 quit; 

     %end;

          proc sql noprint;
            insert into config.plan_thread
            values(&plan_id.,&GL_FORECAST_THREADS_NO.)
            ;
          quit;

	
	%let table_exist = %sysfunc(exist(abt.Plan_hier_filtered_leaf_val&plan_id.));
    	%if &table_exist. eq 0 %then %do;

			%ddcf_plan_hier_filter_leaf;
		%end;
	%ddcf_initiate_abt_creation;
	%ddcf_initiate_abt_indep_creation;

	%ddcf_create_plan_stf_abt;

	%if &indep_num. > 0 %then %do;
       %ddcf_create_plan_stf_abt_indep;
    %end;
	
	%if &Incremental_forecast_flag. ne &GL_SHORT_YES. %then %do;
		%ddcf_create_tab_for_invalid_plan
		%ddcf_plan_create_successors_abt;
/*added 5th Feb 2013 */
		proc sql noprint;
			select count(*) into: npf_count from control.NPF_plan_control_data&plan_id.;
		quit;

		  proc sql noprint;
	         select count(*) into: stf_count 
	         from control.plan_control_data&plan_id.; 
		  quit; 
/*added 5th Feb 2013 */
	%end;

    %ddcf_call_hier_creation;

	%if &indep_num. > 0 %then %do;
       %ddcf_call_hier_creation_indep;
    %end;

	/**********Creating UIARTs for Model Management View*************/
	%ddcf_uiart_create_fcst_plan_stp;

	/* Create folders for reporting tables*/
/*	%if &GL_INCLUDE_ARCHIVE_IND. = 1 %then %do;*/
/*		%ddcf_create_archive_dir(plan_id=&plan_id.);*/
/*	%end;*/

/* if any error has occured while deleting a plan, then no need of creating the plan again, only show
the error message in plan_details*/
%end_plan:

%if &GL_FRAMEWORK_DB_IND.=&GL_SHORT_NO. %then %do;
	libname uiart clear;
%end;

%mend ddcf_create_forecast_plan;
%ddcf_create_forecast_plan;
