/*-- Copyright (c) 2011 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
Model         	DDCF FM Integration  
Subject Area  	Financial Management Integration
Version
Name          	DDCF 5.3: Macro to complete consensus process
DBMS          	SAS
Created by 		Abhijeet Murumkar, Ganesh Gurunathan
Created on 		17/06/2011 14:45:00 PM
Last updated 	20/01/2012 10:15:00 AM

* Copyright (c) 2011 by SAS Institute Inc., Cary, NC 27513

Input Parameters 
1. plan_id		Plan identification number

History:

# Renamed DDF to FAW 	20/01/2012 10:15:00 AM

*/

data _null_;
	call symputx('VarDtStr',TRANWRD(('_'|| put(date(),YYMMDDN.) || '_' || put(time(),HHMM.) || '.log'),':','_'));
run;

%let logfilenm=complete_%sysfunc(ktrim(&plan_id.))&VarDtStr.;
%let logfilepath=&GL_DDF_CONFIG_DIR_PATH./logs/;

proc printto log="&logfilepath.&logfilenm."; 
run;

%macro ddcf_fm_complete_formset_stp;

	%if &GL_FRAMEWORK_DB_IND.=&GL_SHORT_NO. %then %do;
		libname uiart MYSQL  INSERTBUFF=&GL_MYSQL_INSERTBUFF. DBINDEX=YES bulkload = yes  MYSQL_PORT=3306 DBCONINIT = &GL_MYSQL_DBCONINIT.
		DATABASE=&GL_TRANS_DATABASE_NM. SERVER="&GL_TRANS_DB_SERVER."  authdomain = &GL_MYSQL_AUTH_DOMAIN. ; 
	%end;

	libname sassdm MYSQL  INSERTBUFF=&GL_MYSQL_INSERTBUFF. DBINDEX=YES bulkload = yes  MYSQL_PORT=3306 DBCONINIT = &GL_MYSQL_DBCONINIT.
	DATABASE=&GL_FM_MYSQL_DATABASE_NM. SERVER="&GL_FM_MYSQL_SERVER."  authdomain = &GL_FM_MYSQL_AUTH_DOMAIN. ;

	
	/* Define connection string for transactional server*/

	%ddcf_connect_to_trans_db;
	
	%let job_rc=0;
	%let job_rc_msg=;

	/* Get schema id */

	%let schema_id=;
	%ddcf_get_schema_id(plan_id=&plan_id.);
	%let schema_id=%sysfunc(ktrim(%sysfunc(kleft(&schema_id.))));
	
	/* Complete Form Set */

	%if (&job_rc<5) %then %do;
		
		%let cycle_id=0;

		proc sql noprint;
			select cycle_id into :cycle_id
			from sassdm.sas_cycle_data
			where ktrim(kleft(kupcase(cycle_nm))) = %sysfunc(kupcase("&schema_id."));
		quit;
		%rcset(&sqlrc);

		%if (&job_rc>4) %then %do;
			%put "Error: Failed while Write back process."; 
			%goto exit;
		%end;

		%if &cycle_id. > 0 %then %do;

			proc sql noprint;
				select form_set_nm into :form_set_nms separated by ','
				from sassdm.sas_form_set
				where cycle_id = &cycle_id.;
			quit;
			%rcset(&sqlrc);

			%if (&job_rc>4) %then %do;
				%put "Error: Failed while Write back process."; 
				%goto exit;
			%end;

			%let k=1;

			%let blist=%sysfunc(kscan(%quote(%sysfunc(strip(&form_set_nms.))),&k., %str(,)));
					
			%do %while (%quote(&blist.) ne);

					%let formset=;
					%let formset=%nrquote(%sysfunc(kleft(%sysfunc(ktrim(&blist.)))));
					%let k=%eval(&k.+1);

					data _null_ /picklist='finance/finance.txt';
				   		declare javaobj formset;
						formset=_new_ javaobj("com/sas/solutions/finance/api/FormSet");
						formset.ExceptionDescribe(1);
						
						call METADATA_PASSID("formset", "");
						formset.callVoidMethod('setCycleName',"&schema_id.");
						formset.callVoidMethod('setFormSetName',"&formset.");
						
				 		formset.callVoidMethod('completeFormSet');
					 run;
					 %rcset(&syserr);

					 %if (&job_rc>4) %then %do;
						%goto exit;
					%end;

					%let blist=%sysfunc(kscan(%quote(%sysfunc(strip(&form_set_nms.))),&k., %str(,)));
			%end; 

		%end;
	%end;

	/* Writeback process */

	/* WORKFLOW: DDCF CONSENSUS PLAN : To Extract Fact Data */

	 %let dimension=FAW_ANALYSIS;
	 %let dsname=scratch.output_plan_&plan_id.;

	 %if (&job_rc < 5) %then %do;
		%ddcf_fm_sdm_extract_facts(plan_id=&plan_id.,dimension=&dimension.,dsname=&dsname.);
	%end;
	%if (&job_rc < 5) %then %do;
		%ddcf_fm_update_consensus(config=config,stage=stagefm,uiart=uiart,plan_id=&plan_id.,facttable=plan_forecast_fact,dsname=&dsname.);

		%if (&job_rc < 5) %then %do;
			proc sql noprint;
				update uiart.plan_consensus_details 
				set STATUS_CD = 19 
				where plan_id = &plan_id.;
			quit;
			%rcset(&sqlrc);

			/* Change Plan Status to Planning Complete */

			proc sql noprint;
				update uiart.plan_details 
				set PLAN_STATUS_NO = 13 
				where plan_id = &plan_id.;
			quit;
			%rcset(&sqlrc);
		%end;
		%else %do;
			proc sql noprint;
				update uiart.plan_consensus_details 
				set STATUS_CD = 18 
				where plan_id = &plan_id.;
			quit;
			%rcset(&sqlrc);
		%end;

				/* Archive fact data set */
		%if (&job_rc < 5) and (&GL_INCLUDE_ARCHIVE_IND. = 1) %then %do;
			%ddcf_fm_copy_to_archive(plan_id=&plan_id.,facttable=plan_forecast_fact);
		%end;
	%end;
	%else %do;
		proc sql noprint;
			update uiart.plan_consensus_details 
			set STATUS_CD = 18 
			where plan_id = &plan_id.;
		quit;
		%rcset(&sqlrc);
	%end;

	libname sassdm clear;

%exit:	

%if &GL_FRAMEWORK_DB_IND.=&GL_SHORT_NO. %then %do;
	libname uiart clear;
%end;

%mend;
%ddcf_fm_complete_formset_stp;
proc printto; 
run;
